@@ -69,8 +69,8 @@ class Device:
         return self.license_plate.replace("-", "")
 
     @property
-    def object_name(self):
-        """Compose a friendly name."""
+    def friendly_name(self):
+        """Compose a friendly device name."""
         return f"{self.license_plate} {self.make} {self.model}"
 
     @property
